@@ -6,7 +6,7 @@ script_path <- (function() {
     return("R")
   }
   if (grepl("darwin", R.version$os)) {
-    base <- gsub("~\\+~", " ", base) # on MacOS ~+~ in path denotes whitespace
+    script_path <- gsub("~\\+~", " ", script_path) # on MacOS ~+~ in path denotes whitespace
   }
   return(normalizePath(script_path))
 })()
