@@ -17,7 +17,8 @@
 assert <- function(cond, fail_msg = NULL, ...) {
   if (!cond) {
     if (is.null(fail_msg) || missing(fail_msg)) {
-      fail_msg <- sprintf("Condition failed: %s", deparse(substitute(cond), width.cutoff = 30L))
+      fail_msg <- sprintf("Condition failed: %s", 
+                          deparse(substitute(cond), width.cutoff = 30L))
     } else {
       fail_msg <- sprintf(fail_msg, ...)
     }
